@@ -1,5 +1,6 @@
 import base64
 import datetime
+import json
 import logging
 import os
 from typing import Any, Dict, List
@@ -131,9 +132,46 @@ class BaseAPI:
             resp = self._http.api._send(obj=obj, activity_type="Add", group_id=group_id)
 
     def download_files(self, file_dir, group_id=None):
-        infos, trxs = self.search_file_trxs(group_id)
+        utils.check_dir(file_dir)
+        infos, trxs = self.search_file_trxs(group_id=group_id)
         utils.merge_trxs_to_files(file_dir, infos, trxs)
 
+    def get_contents(
+        self,
+        trx_id=None,
+        group_id=None,
+        senders=None,
+        trx_types=None,
+        reverse=False,
+        num=20,
+    ):
+        """返回的是一个生成器，可以用 for ... in ... 来迭代访问。trx_types 的取值见 utils.trx_type() 的各种返回值"""
+        trxs = self._http.api.get_group_content(group_id=group_id, trx_id=trx_id, num=num, reverse=reverse)
+        checked_trxids = []
+        trx_types = trx_types or []
+        senders = senders or []
+        got_num = 0
+        stop = False
+        while trxs and not stop:
+            if trx_id in checked_trxids:
+                break
+            else:
+                checked_trxids.append(trx_id)
+            for trx in trxs:
+                if got_num < num:
+                    flag1 = (utils.trx_type(trx) in trx_types) or (not trx_types)
+                    flag2 = (trx.get("Publisher", "") in senders) or (not senders)
+                    if flag1 and flag2:
+                        got_num += 1
+                        yield trx
+                else:
+                    stop = True
+                    break
+            if stop:
+                break
+            trx_id = utils.get_last_trxid_by_chain(trx_id, trxs, reverse=reverse)
+            trxs = self._http.api.get_group_content(group_id=group_id, trx_id=trx_id, num=num, reverse=reverse)
+
     def get_group_all_contents(
         self,
         trx_id=None,
@@ -178,14 +216,16 @@ class BaseAPI:
             reverse=False,
         )
         users = users or {}
+        progress_tid = trx_id
         for trx in trxs:
+            progress_tid = trx["TrxId"]
             if trx_content := trx.get("Content"):
                 pubkey = trx["Publisher"]
                 users[pubkey] = users.get(pubkey, {})
                 for key in trx_content:
                     if key in types:
                         users[pubkey].update({key: trx_content[key]})
-        users["progress_tid"] = utils.get_last_trxid_by_ts(trxs)
+        users["progress_tid"] = progress_tid
         return users
 
     def update_profiles_data(
@@ -242,3 +282,14 @@ class BaseAPI:
             }
         )
         return users_data
+
+    def groups(self) -> List:
+        resp = self._http.api._groups()
+        if "groups" in resp:
+            return resp["groups"]
+        raise RumException(500, json.dumps(resp))
+
+    @property
+    def groups_id(self) -> List:
+        """return list of group_id which node has joined"""
+        return [i["group_id"] for i in self.groups()]
