@@ -11,7 +11,6 @@ import uuid
 from typing import Any, Dict, List
 from urllib import parse
 
-import certifi
 import filetype
 from PIL import Image
 
@@ -21,6 +20,11 @@ from rumpy.types.data import *
 logger = logging.getLogger(__name__)
 
 
+def check_dir(dirpath):
+    if not os.path.exists(dirpath):
+        os.makedirs(dirpath)
+
+
 def check_trx_mode(mode: str):
     if mode.lower() not in ["dny", "deny", "allow", "alw"]:
         raise ParamValueError(f"{mode} mode must be one of ['deny','allow']")
@@ -39,6 +43,8 @@ def check_trx_type(trx_type: str):
 def check_crtfile(crtfile):
     try:
         if not os.path.exists(crtfile):
+            import certifi
+
             crtfile = certifi.where()
     except:
         crtfile = True
@@ -244,7 +250,7 @@ def split_file_to_trx_objs(path_bytes_string):
     fileinfo = {
         "mediaType": filetype.guess(file_bytes).mime,
         "name": file_name,
-        "title": file_name.split(".")[0],
+        "title": os.path.splitext(file_name)[0],
         "sha256": sha256(file_bytes),
         "segments": [],
     }
@@ -463,15 +469,15 @@ def get_last_trxid_by_chain(trx_id: str, trxs: List, reverse=False):
     return trx_id
 
 
-def get_last_trxid_by_ts(trx_id: str, trxs, reverse=False):
+def get_last_trxid_by_ts(trx_id: str, trxs, reverse=False):  # TODO:这个方法不好，相关调用要改写
     """get the last trx_id of trxs <type: generator> which if different from given trx_id by trx timestamp"""
     _ts = datetime.datetime.now() + datetime.timedelta(weeks=-520)
     _tid = None
-    for trx, tid in trxs:
+    for trx in trxs:
         ts = trx_ts(trx, "datetime")
         if ts > _ts:
             _ts = ts
-            _tid = tid
+            _tid = trx["TrxId"]
     if _tid and _tid != trx_id:
         return _tid, _ts
     return trx_id, _ts
